@@ -6,7 +6,7 @@ from PIL import Image
 import torch
 from torch.utils.data import Dataset, DataLoader
 from ultocr.utils.download import download_weights
-from ultocr.utils.utils_function import create_module, change_state_dict
+from ultocr.utils.utils_function import create_module
 from ultocr.loader.recognition.reg_loader import TextInference
 from ultocr.utils.det_utils import four_point_transform, sort_by_line, test_preprocess, draw_bbox
 from ultocr.loader.recognition.translate import LabelConverter
@@ -86,7 +86,8 @@ class Recognition:
         self.img_h = cfg['dataset']['new_shape'][1]
         self.batch = 16
         vocab_file = download_weights('1Lo9L_k63M7vpiR10zii5nzL4GGUSuntM')
-        self.convert = LabelConverter(classes=vocab_file, max_length=100, ignore_over=False)
+        self.convert = LabelConverter(classes=vocab_file, max_length=cfg['post_process']['max_len'], ignore_over=False)
+        cfg['dataset']['vocab'] = vocab_file
         model = create_module(cfg['model']['function'])(cfg)
         state_dict = torch.load(weight, map_location=self.device)['model_state_dict']
         model.load_state_dict(state_dict)
@@ -114,6 +115,8 @@ class Recognition:
             
             for index, (pred, prob) in enumerate(zip(outputs[:, 1:], probs)):
                 pred_text = ''
+                previous_text = None
+                repeat = 0
                 pred_score_list = []
                 for i in range(len(pred)):
                     if pred[i] == self.convert.EOS:
@@ -123,6 +126,11 @@ class Recognition:
                         continue
 
                     decoder_char = self.convert.decode(pred[i])
+                    if decoder_char == previous_text:
+                        repeat += 1
+                    previous_text = decoder_char
+                    if repeat == 5:
+                        break
                     pred_text += decoder_char
                     pred_score_list.append(prob[i])
                 
@@ -170,6 +178,7 @@ class OCR:
         det_result = self.detection.detect(img)
         img_rs = det_result['img']
         all_img_crop = det_result['boundary_result']
+        boxes_coordinate = det_result['box_coordinate']
         if len(all_img_crop) == 0:
             result = 'khong co text trong anh'
             return result
@@ -178,5 +187,11 @@ class OCR:
             img_pil = Image.fromarray(img_crop.astype('uint8'), 'RGB')
             all_img_pil.append(img_pil)
         result = self.recognition.recognize(all_img_pil)
+        infos = ''
+        for box, text in zip(boxes_coordinate, result):
+            box = list(map(str, box))
+            box = ','.join(box)
+            infos += box + ',' + text + '\n'
         return result
 
+
