@@ -2,6 +2,7 @@ import numpy as np
 import torch
 import torch.nn as nn
 from copy import deepcopy
+from ultocr.utils.download import download_weights
 from ultocr.utils.utils_function import create_module
 from ultocr.loader.recognition.translate import LabelConverter
 from ultocr.model.common.transformer import EncoderLayer, DecoderLayer, Encoder, Decoder, Embeddings
@@ -21,7 +22,8 @@ class MASTER(nn.Module):
     def __init__(self, config):
         super().__init__()
         self.config = config
-        self.convert = LabelConverter(classes=config['dataset']['vocab'], max_length=100, ignore_over=False)
+        # vocab_file = download_weights('1Lo9L_k63M7vpiR10zii5nzL4GGUSuntM')
+        self.convert = LabelConverter(classes=config['dataset']['vocab'], max_length=config['post_process']['max_len'], ignore_over=False)
         tgt_vocab = self.convert.n_class
         self.with_encoder = config['model']['common']['with_encoder']
         for p in self.parameters():
